@@ -1,37 +1,7 @@
-#=======================================================================
-#    ____  ____  _____              _    ____ ___   ____
-#   |  _ \|  _ \|  ___|  _   _     / \  |  _ \_ _| |___ \
-#   | |_) | | | | |_    (_) (_)   / _ \ | |_) | |    __) |
-#   |  __/| |_| |  _|    _   _   / ___ \|  __/| |   / __/
-#   |_|   |____/|_|     (_) (_) /_/   \_\_|  |___| |_____|
-#
-#   A Perl Module Chain to faciliate the Creation and Modification
-#   of High-Quality "Portable Document Format (PDF)" Files.
-#
-#   Copyright 1999-2005 Alfred Reibenschuh <areibens@cpan.org>.
-#
-#=======================================================================
-#
-#   This library is free software; you can redistribute it and/or
-#   modify it under the terms of the GNU Lesser General Public
-#   License as published by the Free Software Foundation; either
-#   version 2 of the License, or (at your option) any later version.
-#
-#   This library is distributed in the hope that it will be useful,
-#   but WITHOUT ANY WARRANTY; without even the implied warranty of
-#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-#   Lesser General Public License for more details.
-#
-#   You should have received a copy of the GNU Lesser General Public
-#   License along with this library; if not, write to the
-#   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-#   Boston, MA 02111-1307, USA.
-#
-#   $Id: courier.pm,v 2.0 2005/11/16 02:18:14 areibens Exp $ 
-#
-#=======================================================================
 package PDF::API2::Resource::Font::CoreFont::courier;
 
+our $VERSION = '2.023'; # VERSION
+
 $FONTDATA = {
     'fontname' => 'Courier',
     'type' => 'Type1',
@@ -49,264 +19,264 @@ $FONTDATA = {
     'firstchar' => '32',
     'lastchar' => '255',
     'fontbbox' => [-23, -250, 715, 805],
-    'char' => [
-        '.notdef',           # C+00, U+0000
-        '.notdef',           # C+01, U+0000
-        '.notdef',           # C+02, U+0000
-        '.notdef',           # C+03, U+0000
-        '.notdef',           # C+04, U+0000
-        '.notdef',           # C+05, U+0000
-        '.notdef',           # C+06, U+0000
-        '.notdef',           # C+07, U+0000
-        '.notdef',           # C+08, U+0000
-        '.notdef',           # C+09, U+0000
-        '.notdef',           # C+0A, U+0000
-        '.notdef',           # C+0B, U+0000
-        '.notdef',           # C+0C, U+0000
-        '.notdef',           # C+0D, U+0000
-        '.notdef',           # C+0E, U+0000
-        '.notdef',           # C+0F, U+0000
-        '.notdef',           # C+10, U+0000
-        '.notdef',           # C+11, U+0000
-        '.notdef',           # C+12, U+0000
-        '.notdef',           # C+13, U+0000
-        '.notdef',           # C+14, U+0000
-        '.notdef',           # C+15, U+0000
-        '.notdef',           # C+16, U+0000
-        '.notdef',           # C+17, U+0000
-        '.notdef',           # C+18, U+0000
-        '.notdef',           # C+19, U+0000
-        '.notdef',           # C+1A, U+0000
-        '.notdef',           # C+1B, U+0000
-        '.notdef',           # C+1C, U+0000
-        '.notdef',           # C+1D, U+0000
-        '.notdef',           # C+1E, U+0000
-        '.notdef',           # C+1F, U+0000
-        'space',             # C+20, U+0020
-        'exclam',            # C+21, U+0021
-        'quotedbl',          # C+22, U+0022
-        'numbersign',        # C+23, U+0023
-        'dollar',            # C+24, U+0024
-        'percent',           # C+25, U+0025
-        'ampersand',         # C+26, U+0026
-        'quoteright',        # C+27, U+2019
-        'parenleft',         # C+28, U+0028
-        'parenright',        # C+29, U+0029
-        'asterisk',          # C+2A, U+002A
-        'plus',              # C+2B, U+002B
-        'comma',             # C+2C, U+002C
-        'hyphen',            # C+2D, U+002D
-        'period',            # C+2E, U+002E
-        'slash',             # C+2F, U+002F
-        'zero',              # C+30, U+0030
-        'one',               # C+31, U+0031
-        'two',               # C+32, U+0032
-        'three',             # C+33, U+0033
-        'four',              # C+34, U+0034
-        'five',              # C+35, U+0035
-        'six',               # C+36, U+0036
-        'seven',             # C+37, U+0037
-        'eight',             # C+38, U+0038
-        'nine',              # C+39, U+0039
-        'colon',             # C+3A, U+003A
-        'semicolon',         # C+3B, U+003B
-        'less',              # C+3C, U+003C
-        'equal',             # C+3D, U+003D
-        'greater',           # C+3E, U+003E
-        'question',          # C+3F, U+003F
-        'at',                # C+40, U+0040
-        'A',                 # C+41, U+0041
-        'B',                 # C+42, U+0042
-        'C',                 # C+43, U+0043
-        'D',                 # C+44, U+0044
-        'E',                 # C+45, U+0045
-        'F',                 # C+46, U+0046
-        'G',                 # C+47, U+0047
-        'H',                 # C+48, U+0048
-        'I',                 # C+49, U+0049
-        'J',                 # C+4A, U+004A
-        'K',                 # C+4B, U+004B
-        'L',                 # C+4C, U+004C
-        'M',                 # C+4D, U+004D
-        'N',                 # C+4E, U+004E
-        'O',                 # C+4F, U+004F
-        'P',                 # C+50, U+0050
-        'Q',                 # C+51, U+0051
-        'R',                 # C+52, U+0052
-        'S',                 # C+53, U+0053
-        'T',                 # C+54, U+0054
-        'U',                 # C+55, U+0055
-        'V',                 # C+56, U+0056
-        'W',                 # C+57, U+0057
-        'X',                 # C+58, U+0058
-        'Y',                 # C+59, U+0059
-        'Z',                 # C+5A, U+005A
-        'bracketleft',       # C+5B, U+005B
-        'backslash',         # C+5C, U+005C
-        'bracketright',      # C+5D, U+005D
-        'asciicircum',       # C+5E, U+005E
-        'underscore',        # C+5F, U+005F
-        'quoteleft',         # C+60, U+2018
-        'a',                 # C+61, U+0061
-        'b',                 # C+62, U+0062
-        'c',                 # C+63, U+0063
-        'd',                 # C+64, U+0064
-        'e',                 # C+65, U+0065
-        'f',                 # C+66, U+0066
-        'g',                 # C+67, U+0067
-        'h',                 # C+68, U+0068
-        'i',                 # C+69, U+0069
-        'j',                 # C+6A, U+006A
-        'k',                 # C+6B, U+006B
-        'l',                 # C+6C, U+006C
-        'm',                 # C+6D, U+006D
-        'n',                 # C+6E, U+006E
-        'o',                 # C+6F, U+006F
-        'p',                 # C+70, U+0070
-        'q',                 # C+71, U+0071
-        'r',                 # C+72, U+0072
-        's',                 # C+73, U+0073
-        't',                 # C+74, U+0074
-        'u',                 # C+75, U+0075
-        'v',                 # C+76, U+0076
-        'w',                 # C+77, U+0077
-        'x',                 # C+78, U+0078
-        'y',                 # C+79, U+0079
-        'z',                 # C+7A, U+007A
-        'braceleft',         # C+7B, U+007B
-        'bar',               # C+7C, U+007C
-        'braceright',        # C+7D, U+007D
-        'asciitilde',        # C+7E, U+007E
-        '.notdef',           # C+7F, U+0000
-        'Euro',              # C+80, U+20AC
-        'bullet',            # C+81, U+2022
-        'quotesinglbase',    # C+82, U+201A
-        'florin',            # C+83, U+0192
-        'quotedblbase',      # C+84, U+201E
-        'ellipsis',          # C+85, U+2026
-        'dagger',            # C+86, U+2020
-        'daggerdbl',         # C+87, U+2021
-        'circumflex',        # C+88, U+02C6
-        'perthousand',       # C+89, U+2030
-        'Scaron',            # C+8A, U+0160
-        'guilsinglleft',     # C+8B, U+2039
-        'OE',                # C+8C, U+0152
-        'bullet',            # C+8D, U+2022
-        'Zcaron',            # C+8E, U+017D
-        'bullet',            # C+8F, U+2022
-        'bullet',            # C+90, U+2022
-        'quoteleft',         # C+91, U+2018
-        'quoteright',        # C+92, U+2019
-        'quotedblleft',      # C+93, U+201C
-        'quotedblright',     # C+94, U+201D
-        'bullet',            # C+95, U+2022
-        'endash',            # C+96, U+2013
-        'emdash',            # C+97, U+2014
-        'tilde',             # C+98, U+02DC
-        'trademark',         # C+99, U+2122
-        'scaron',            # C+9A, U+0161
-        'guilsinglright',    # C+9B, U+203A
-        'oe',                # C+9C, U+0153
-        'bullet',            # C+9D, U+2022
-        'zcaron',            # C+9E, U+017E
-        'Ydieresis',         # C+9F, U+0178
-        'space',             # C+A0, U+0020
-        'exclamdown',        # C+A1, U+00A1
-        'cent',              # C+A2, U+00A2
-        'sterling',          # C+A3, U+00A3
-        'fraction',          # C+A4, U+2044
-        'yen',               # C+A5, U+00A5
-        'florin',            # C+A6, U+0192
-        'section',           # C+A7, U+00A7
-        'currency',          # C+A8, U+00A4
-        'quotesingle',       # C+A9, U+0027
-        'quotedblleft',      # C+AA, U+201C
-        'guillemotleft',     # C+AB, U+00AB
-        'guilsinglleft',     # C+AC, U+2039
-        'guilsinglright',    # C+AD, U+203A
-        'fi',                # C+AE, U+FB01
-        'fl',                # C+AF, U+FB02
-        'degree',            # C+B0, U+00B0
-        'endash',            # C+B1, U+2013
-        'dagger',            # C+B2, U+2020
-        'daggerdbl',         # C+B3, U+2021
-        'periodcentered',    # C+B4, U+00B7
-        'mu',                # C+B5, U+00B5
-        'paragraph',         # C+B6, U+00B6
-        'bullet',            # C+B7, U+2022
-        'quotesinglbase',    # C+B8, U+201A
-        'quotedblbase',      # C+B9, U+201E
-        'quotedblright',     # C+BA, U+201D
-        'guillemotright',    # C+BB, U+00BB
-        'ellipsis',          # C+BC, U+2026
-        'perthousand',       # C+BD, U+2030
-        'threequarters',     # C+BE, U+00BE
-        'questiondown',      # C+BF, U+00BF
-        'Agrave',            # C+C0, U+00C0
-        'grave',             # C+C1, U+0060
-        'acute',             # C+C2, U+00B4
-        'circumflex',        # C+C3, U+02C6
-        'tilde',             # C+C4, U+02DC
-        'macron',            # C+C5, U+00AF
-        'breve',             # C+C6, U+02D8
-        'dotaccent',         # C+C7, U+02D9
-        'dieresis',          # C+C8, U+00A8
-        'Eacute',            # C+C9, U+00C9
-        'ring',              # C+CA, U+02DA
-        'cedilla',           # C+CB, U+00B8
-        'Igrave',            # C+CC, U+00CC
-        'hungarumlaut',      # C+CD, U+02DD
-        'ogonek',            # C+CE, U+02DB
-        'caron',             # C+CF, U+02C7
-        'emdash',            # C+D0, U+2014
-        'Ntilde',            # C+D1, U+00D1
-        'Ograve',            # C+D2, U+00D2
-        'Oacute',            # C+D3, U+00D3
-        'Ocircumflex',       # C+D4, U+00D4
-        'Otilde',            # C+D5, U+00D5
-        'Odieresis',         # C+D6, U+00D6
-        'multiply',          # C+D7, U+00D7
-        'Oslash',            # C+D8, U+00D8
-        'Ugrave',            # C+D9, U+00D9
-        'Uacute',            # C+DA, U+00DA
-        'Ucircumflex',       # C+DB, U+00DB
-        'Udieresis',         # C+DC, U+00DC
-        'Yacute',            # C+DD, U+00DD
-        'Thorn',             # C+DE, U+00DE
-        'germandbls',        # C+DF, U+00DF
-        'agrave',            # C+E0, U+00E0
-        'AE',                # C+E1, U+00C6
-        'acircumflex',       # C+E2, U+00E2
-        'ordfeminine',       # C+E3, U+00AA
-        'adieresis',         # C+E4, U+00E4
-        'aring',             # C+E5, U+00E5
-        'ae',                # C+E6, U+00E6
-        'ccedilla',          # C+E7, U+00E7
-        'Lslash',            # C+E8, U+0141
-        'Oslash',            # C+E9, U+00D8
-        'OE',                # C+EA, U+0152
-        'ordmasculine',      # C+EB, U+00BA
-        'igrave',            # C+EC, U+00EC
-        'iacute',            # C+ED, U+00ED
-        'icircumflex',       # C+EE, U+00EE
-        'idieresis',         # C+EF, U+00EF
-        'eth',               # C+F0, U+00F0
-        'ae',                # C+F1, U+00E6
-        'ograve',            # C+F2, U+00F2
-        'oacute',            # C+F3, U+00F3
-        'ocircumflex',       # C+F4, U+00F4
-        'dotlessi',          # C+F5, U+0131
-        'odieresis',         # C+F6, U+00F6
-        'divide',            # C+F7, U+00F7
-        'lslash',            # C+F8, U+0142
-        'oslash',            # C+F9, U+00F8
-        'oe',                # C+FA, U+0153
-        'germandbls',        # C+FB, U+00DF
-        'udieresis',         # C+FC, U+00FC
-        'yacute',            # C+FD, U+00FD
-        'thorn',             # C+FE, U+00FE
-        'ydieresis',         # C+FF, U+00FF
-    ],
+    'char' => [ # DEF. ENCODING GLYPH TABLE
+        '.notdef',                               # C+0x00 # U+0x0000
+        '.notdef',                               # C+0x01 # U+0x0000
+        '.notdef',                               # C+0x02 # U+0x0000
+        '.notdef',                               # C+0x03 # U+0x0000
+        '.notdef',                               # C+0x04 # U+0x0000
+        '.notdef',                               # C+0x05 # U+0x0000
+        '.notdef',                               # C+0x06 # U+0x0000
+        '.notdef',                               # C+0x07 # U+0x0000
+        '.notdef',                               # C+0x08 # U+0x0000
+        '.notdef',                               # C+0x09 # U+0x0000
+        '.notdef',                               # C+0x0A # U+0x0000
+        '.notdef',                               # C+0x0B # U+0x0000
+        '.notdef',                               # C+0x0C # U+0x0000
+        '.notdef',                               # C+0x0D # U+0x0000
+        '.notdef',                               # C+0x0E # U+0x0000
+        '.notdef',                               # C+0x0F # U+0x0000
+        '.notdef',                               # C+0x10 # U+0x0000
+        '.notdef',                               # C+0x11 # U+0x0000
+        '.notdef',                               # C+0x12 # U+0x0000
+        '.notdef',                               # C+0x13 # U+0x0000
+        '.notdef',                               # C+0x14 # U+0x0000
+        '.notdef',                               # C+0x15 # U+0x0000
+        '.notdef',                               # C+0x16 # U+0x0000
+        '.notdef',                               # C+0x17 # U+0x0000
+        '.notdef',                               # C+0x18 # U+0x0000
+        '.notdef',                               # C+0x19 # U+0x0000
+        '.notdef',                               # C+0x1A # U+0x0000
+        '.notdef',                               # C+0x1B # U+0x0000
+        '.notdef',                               # C+0x1C # U+0x0000
+        '.notdef',                               # C+0x1D # U+0x0000
+        '.notdef',                               # C+0x1E # U+0x0000
+        '.notdef',                               # C+0x1F # U+0x0000
+        'space',                                 # C+0x20 # U+0x0020
+        'exclam',                                # C+0x21 # U+0x0021
+        'quotedbl',                              # C+0x22 # U+0x0022
+        'numbersign',                            # C+0x23 # U+0x0023
+        'dollar',                                # C+0x24 # U+0x0024
+        'percent',                               # C+0x25 # U+0x0025
+        'ampersand',                             # C+0x26 # U+0x0026
+        'quotesingle',                           # C+0x27 # U+0x0027
+        'parenleft',                             # C+0x28 # U+0x0028
+        'parenright',                            # C+0x29 # U+0x0029
+        'asterisk',                              # C+0x2A # U+0x002A
+        'plus',                                  # C+0x2B # U+0x002B
+        'comma',                                 # C+0x2C # U+0x002C
+        'hyphen',                                # C+0x2D # U+0x002D
+        'period',                                # C+0x2E # U+0x002E
+        'slash',                                 # C+0x2F # U+0x002F
+        'zero',                                  # C+0x30 # U+0x0030
+        'one',                                   # C+0x31 # U+0x0031
+        'two',                                   # C+0x32 # U+0x0032
+        'three',                                 # C+0x33 # U+0x0033
+        'four',                                  # C+0x34 # U+0x0034
+        'five',                                  # C+0x35 # U+0x0035
+        'six',                                   # C+0x36 # U+0x0036
+        'seven',                                 # C+0x37 # U+0x0037
+        'eight',                                 # C+0x38 # U+0x0038
+        'nine',                                  # C+0x39 # U+0x0039
+        'colon',                                 # C+0x3A # U+0x003A
+        'semicolon',                             # C+0x3B # U+0x003B
+        'less',                                  # C+0x3C # U+0x003C
+        'equal',                                 # C+0x3D # U+0x003D
+        'greater',                               # C+0x3E # U+0x003E
+        'question',                              # C+0x3F # U+0x003F
+        'at',                                    # C+0x40 # U+0x0040
+        'A',                                     # C+0x41 # U+0x0041
+        'B',                                     # C+0x42 # U+0x0042
+        'C',                                     # C+0x43 # U+0x0043
+        'D',                                     # C+0x44 # U+0x0044
+        'E',                                     # C+0x45 # U+0x0045
+        'F',                                     # C+0x46 # U+0x0046
+        'G',                                     # C+0x47 # U+0x0047
+        'H',                                     # C+0x48 # U+0x0048
+        'I',                                     # C+0x49 # U+0x0049
+        'J',                                     # C+0x4A # U+0x004A
+        'K',                                     # C+0x4B # U+0x004B
+        'L',                                     # C+0x4C # U+0x004C
+        'M',                                     # C+0x4D # U+0x004D
+        'N',                                     # C+0x4E # U+0x004E
+        'O',                                     # C+0x4F # U+0x004F
+        'P',                                     # C+0x50 # U+0x0050
+        'Q',                                     # C+0x51 # U+0x0051
+        'R',                                     # C+0x52 # U+0x0052
+        'S',                                     # C+0x53 # U+0x0053
+        'T',                                     # C+0x54 # U+0x0054
+        'U',                                     # C+0x55 # U+0x0055
+        'V',                                     # C+0x56 # U+0x0056
+        'W',                                     # C+0x57 # U+0x0057
+        'X',                                     # C+0x58 # U+0x0058
+        'Y',                                     # C+0x59 # U+0x0059
+        'Z',                                     # C+0x5A # U+0x005A
+        'bracketleft',                           # C+0x5B # U+0x005B
+        'backslash',                             # C+0x5C # U+0x005C
+        'bracketright',                          # C+0x5D # U+0x005D
+        'asciicircum',                           # C+0x5E # U+0x005E
+        'underscore',                            # C+0x5F # U+0x005F
+        'grave',                                 # C+0x60 # U+0x0060
+        'a',                                     # C+0x61 # U+0x0061
+        'b',                                     # C+0x62 # U+0x0062
+        'c',                                     # C+0x63 # U+0x0063
+        'd',                                     # C+0x64 # U+0x0064
+        'e',                                     # C+0x65 # U+0x0065
+        'f',                                     # C+0x66 # U+0x0066
+        'g',                                     # C+0x67 # U+0x0067
+        'h',                                     # C+0x68 # U+0x0068
+        'i',                                     # C+0x69 # U+0x0069
+        'j',                                     # C+0x6A # U+0x006A
+        'k',                                     # C+0x6B # U+0x006B
+        'l',                                     # C+0x6C # U+0x006C
+        'm',                                     # C+0x6D # U+0x006D
+        'n',                                     # C+0x6E # U+0x006E
+        'o',                                     # C+0x6F # U+0x006F
+        'p',                                     # C+0x70 # U+0x0070
+        'q',                                     # C+0x71 # U+0x0071
+        'r',                                     # C+0x72 # U+0x0072
+        's',                                     # C+0x73 # U+0x0073
+        't',                                     # C+0x74 # U+0x0074
+        'u',                                     # C+0x75 # U+0x0075
+        'v',                                     # C+0x76 # U+0x0076
+        'w',                                     # C+0x77 # U+0x0077
+        'x',                                     # C+0x78 # U+0x0078
+        'y',                                     # C+0x79 # U+0x0079
+        'z',                                     # C+0x7A # U+0x007A
+        'braceleft',                             # C+0x7B # U+0x007B
+        'bar',                                   # C+0x7C # U+0x007C
+        'braceright',                            # C+0x7D # U+0x007D
+        'asciitilde',                            # C+0x7E # U+0x007E
+        'bullet',                                # C+0x7F # U+0x2022
+        'Euro',                                  # C+0x80 # U+0x20AC
+        'bullet',                                # C+0x81 # U+0x2022
+        'quotesinglbase',                        # C+0x82 # U+0x201A
+        'florin',                                # C+0x83 # U+0x0192
+        'quotedblbase',                          # C+0x84 # U+0x201E
+        'ellipsis',                              # C+0x85 # U+0x2026
+        'dagger',                                # C+0x86 # U+0x2020
+        'daggerdbl',                             # C+0x87 # U+0x2021
+        'circumflex',                            # C+0x88 # U+0x02C6
+        'perthousand',                           # C+0x89 # U+0x2030
+        'Scaron',                                # C+0x8A # U+0x0160
+        'guilsinglleft',                         # C+0x8B # U+0x2039
+        'OE',                                    # C+0x8C # U+0x0152
+        'bullet',                                # C+0x8D # U+0x2022
+        'Zcaron',                                # C+0x8E # U+0x017D
+        'bullet',                                # C+0x8F # U+0x2022
+        'bullet',                                # C+0x90 # U+0x2022
+        'quoteleft',                             # C+0x91 # U+0x2018
+        'quoteright',                            # C+0x92 # U+0x2019
+        'quotedblleft',                          # C+0x93 # U+0x201C
+        'quotedblright',                         # C+0x94 # U+0x201D
+        'bullet',                                # C+0x95 # U+0x2022
+        'endash',                                # C+0x96 # U+0x2013
+        'emdash',                                # C+0x97 # U+0x2014
+        'tilde',                                 # C+0x98 # U+0x02DC
+        'trademark',                             # C+0x99 # U+0x2122
+        'scaron',                                # C+0x9A # U+0x0161
+        'guilsinglright',                        # C+0x9B # U+0x203A
+        'oe',                                    # C+0x9C # U+0x0153
+        'bullet',                                # C+0x9D # U+0x2022
+        'zcaron',                                # C+0x9E # U+0x017E
+        'Ydieresis',                             # C+0x9F # U+0x0178
+        'space',                                 # C+0xA0 # U+0x0020
+        'exclamdown',                            # C+0xA1 # U+0x00A1
+        'cent',                                  # C+0xA2 # U+0x00A2
+        'sterling',                              # C+0xA3 # U+0x00A3
+        'currency',                              # C+0xA4 # U+0x00A4
+        'yen',                                   # C+0xA5 # U+0x00A5
+        'brokenbar',                             # C+0xA6 # U+0x00A6
+        'section',                               # C+0xA7 # U+0x00A7
+        'dieresis',                              # C+0xA8 # U+0x00A8
+        'copyright',                             # C+0xA9 # U+0x00A9
+        'ordfeminine',                           # C+0xAA # U+0x00AA
+        'guillemotleft',                         # C+0xAB # U+0x00AB
+        'logicalnot',                            # C+0xAC # U+0x00AC
+        'hyphen',                                # C+0xAD # U+0x002D
+        'registered',                            # C+0xAE # U+0x00AE
+        'macron',                                # C+0xAF # U+0x00AF
+        'degree',                                # C+0xB0 # U+0x00B0
+        'plusminus',                             # C+0xB1 # U+0x00B1
+        'twosuperior',                           # C+0xB2 # U+0x00B2
+        'threesuperior',                         # C+0xB3 # U+0x00B3
+        'acute',                                 # C+0xB4 # U+0x00B4
+        'mu',                                    # C+0xB5 # U+0x00B5
+        'paragraph',                             # C+0xB6 # U+0x00B6
+        'periodcentered',                        # C+0xB7 # U+0x00B7
+        'cedilla',                               # C+0xB8 # U+0x00B8
+        'onesuperior',                           # C+0xB9 # U+0x00B9
+        'ordmasculine',                          # C+0xBA # U+0x00BA
+        'guillemotright',                        # C+0xBB # U+0x00BB
+        'onequarter',                            # C+0xBC # U+0x00BC
+        'onehalf',                               # C+0xBD # U+0x00BD
+        'threequarters',                         # C+0xBE # U+0x00BE
+        'questiondown',                          # C+0xBF # U+0x00BF
+        'Agrave',                                # C+0xC0 # U+0x00C0
+        'Aacute',                                # C+0xC1 # U+0x00C1
+        'Acircumflex',                           # C+0xC2 # U+0x00C2
+        'Atilde',                                # C+0xC3 # U+0x00C3
+        'Adieresis',                             # C+0xC4 # U+0x00C4
+        'Aring',                                 # C+0xC5 # U+0x00C5
+        'AE',                                    # C+0xC6 # U+0x00C6
+        'Ccedilla',                              # C+0xC7 # U+0x00C7
+        'Egrave',                                # C+0xC8 # U+0x00C8
+        'Eacute',                                # C+0xC9 # U+0x00C9
+        'Ecircumflex',                           # C+0xCA # U+0x00CA
+        'Edieresis',                             # C+0xCB # U+0x00CB
+        'Igrave',                                # C+0xCC # U+0x00CC
+        'Iacute',                                # C+0xCD # U+0x00CD
+        'Icircumflex',                           # C+0xCE # U+0x00CE
+        'Idieresis',                             # C+0xCF # U+0x00CF
+        'Eth',                                   # C+0xD0 # U+0x00D0
+        'Ntilde',                                # C+0xD1 # U+0x00D1
+        'Ograve',                                # C+0xD2 # U+0x00D2
+        'Oacute',                                # C+0xD3 # U+0x00D3
+        'Ocircumflex',                           # C+0xD4 # U+0x00D4
+        'Otilde',                                # C+0xD5 # U+0x00D5
+        'Odieresis',                             # C+0xD6 # U+0x00D6
+        'multiply',                              # C+0xD7 # U+0x00D7
+        'Oslash',                                # C+0xD8 # U+0x00D8
+        'Ugrave',                                # C+0xD9 # U+0x00D9
+        'Uacute',                                # C+0xDA # U+0x00DA
+        'Ucircumflex',                           # C+0xDB # U+0x00DB
+        'Udieresis',                             # C+0xDC # U+0x00DC
+        'Yacute',                                # C+0xDD # U+0x00DD
+        'Thorn',                                 # C+0xDE # U+0x00DE
+        'germandbls',                            # C+0xDF # U+0x00DF
+        'agrave',                                # C+0xE0 # U+0x00E0
+        'aacute',                                # C+0xE1 # U+0x00E1
+        'acircumflex',                           # C+0xE2 # U+0x00E2
+        'atilde',                                # C+0xE3 # U+0x00E3
+        'adieresis',                             # C+0xE4 # U+0x00E4
+        'aring',                                 # C+0xE5 # U+0x00E5
+        'ae',                                    # C+0xE6 # U+0x00E6
+        'ccedilla',                              # C+0xE7 # U+0x00E7
+        'egrave',                                # C+0xE8 # U+0x00E8
+        'eacute',                                # C+0xE9 # U+0x00E9
+        'ecircumflex',                           # C+0xEA # U+0x00EA
+        'edieresis',                             # C+0xEB # U+0x00EB
+        'igrave',                                # C+0xEC # U+0x00EC
+        'iacute',                                # C+0xED # U+0x00ED
+        'icircumflex',                           # C+0xEE # U+0x00EE
+        'idieresis',                             # C+0xEF # U+0x00EF
+        'eth',                                   # C+0xF0 # U+0x00F0
+        'ntilde',                                # C+0xF1 # U+0x00F1
+        'ograve',                                # C+0xF2 # U+0x00F2
+        'oacute',                                # C+0xF3 # U+0x00F3
+        'ocircumflex',                           # C+0xF4 # U+0x00F4
+        'otilde',                                # C+0xF5 # U+0x00F5
+        'odieresis',                             # C+0xF6 # U+0x00F6
+        'divide',                                # C+0xF7 # U+0x00F7
+        'oslash',                                # C+0xF8 # U+0x00F8
+        'ugrave',                                # C+0xF9 # U+0x00F9
+        'uacute',                                # C+0xFA # U+0x00FA
+        'ucircumflex',                           # C+0xFB # U+0x00FB
+        'udieresis',                             # C+0xFC # U+0x00FC
+        'yacute',                                # C+0xFD # U+0x00FD
+        'thorn',                                 # C+0xFE # U+0x00FE
+        'ydieresis',                             # C+0xFF # U+0x00FF
+    ], # DEF. ENCODING GLYPH TABLE
     'wx' => {
         'A' => '600',   # U=0041
         'a' => '600',   # U=0061
@@ -811,61 +781,3 @@ $FONTDATA = {
         'zdotaccent' => [ 'Z', '0', '0', 'dotaccent', '0', '0' ],   # U=017C
     },
 };
-
-
-__END__
-
-=head1 AUTHOR
-
-alfred reibenschuh
-
-=head1 HISTORY
-
-    $Log: courier.pm,v $
-    Revision 2.0  2005/11/16 02:18:14  areibens
-    revision workaround for SF cvs import not to screw up CPAN
-
-    Revision 1.2  2005/11/16 01:27:50  areibens
-    genesis2
-
-    Revision 1.1  2005/11/16 01:19:27  areibens
-    genesis
-
-    Revision 1.11  2005/09/28 17:00:52  fredo
-    added composites
-
-    Revision 1.10  2005/09/26 19:28:16  fredo
-    no message
-
-    Revision 1.9  2005/09/12 16:56:21  fredo
-    applied mod_perl patch by Paul Schilling <pfschill@sbcglobal.net>
-
-    Revision 1.8  2005/06/07 23:21:39  fredo
-    fontkey correction
-
-    Revision 1.7  2005/03/14 22:01:28  fredo
-    upd 2005
-
-    Revision 1.6  2004/12/16 01:09:12  fredo
-    updated to new adobe afm
-
-    Revision 1.5  2004/06/15 09:14:53  fredo
-    removed cr+lf
-
-    Revision 1.4  2004/06/07 19:44:43  fredo
-    cleaned out cr+lf for lf
-
-    Revision 1.3  2003/12/08 13:06:01  Administrator
-    corrected to proper licencing statement
-
-    Revision 1.2  2003/11/30 17:32:49  Administrator
-    merged into default
-
-    Revision 1.1.1.1.2.2  2003/11/30 16:57:05  Administrator
-    merged into default
-
-    Revision 1.1.1.1.2.1  2003/11/30 15:52:21  Administrator
-    added CVS id/log
-
-
-=cut
